@@ -63,6 +63,7 @@ ArchInputDialog::ArchInputDialog(FXWindow *win,FXString inp):
 	popup=new FXPopup(this);
 	option_tgz = new FXOption(popup,_("tar.gz\tArchive format is tar.gz"),NULL,this,ID_FORMAT_TAR_GZ,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_zip = new FXOption(popup,_("zip\tArchive format is zip"),NULL,this,ID_FORMAT_ZIP,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
+	option_7zip = new FXOption(popup,_("7z\tArchive format is 7z"),NULL,this,ID_FORMAT_7ZIP,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_tbz2 = new FXOption(popup,_("tar.bz2\tArchive format is tar.bz2"),NULL,this,ID_FORMAT_TAR_BZ2,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_tar = new FXOption(popup,_("tar\tArchive format is tar"),NULL,this,ID_FORMAT_TAR,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
 	option_taz = new FXOption(popup,_("tar.Z\tArchive format is tar.Z"),NULL,this,ID_FORMAT_TAR_Z,JUSTIFY_HZ_APART|ICON_AFTER_TEXT);
@@ -166,7 +167,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.gz";
 			input->setText(str);
 		}
-		else if (ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar.gz";
@@ -212,7 +213,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.bz2";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar.bz2";
@@ -268,7 +269,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="zip" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar";
@@ -318,7 +319,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".tar.Z";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
 		{
 			str=str.left(str.length()-4);
 			str=str+".tar.Z";
@@ -374,7 +375,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".gz";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
 		{
 			str=str.left(str.length()-4);
 			str=str+".gz";
@@ -425,7 +426,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".bz2";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="tar" || ext1=="zip" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
 		{
 			str=str.left(str.length()-4);
 			str=str+".bz2";
@@ -481,7 +482,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".Z";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
 		{
 			str=str.left(str.length()-4);
 			str=str+".Z";
@@ -531,7 +532,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".zip";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="rar" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="7z" || ext1=="rar" || ext1=="lzh")
 		{
 			str=str.left(str.length()-4);
 			str=str+".zip";
@@ -556,6 +557,62 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 		}
 	}
 
+	else if (FXSELID(sel)==ID_FORMAT_7ZIP)
+	{
+		// Handle different archive formats
+		if (ext1=="7z")
+		{
+			input->setText(str);
+		}
+		else if (ext2=="tar.bz2")
+		{
+			str=str.left(str.length()-8);
+			str=str+".7z";
+			input->setText(str);
+		}
+		else if (ext2=="tar.gz")
+		{
+			str=str.left(str.length()-7);
+			str=str+".7z";
+			input->setText(str);
+		}
+		else if (ext2=="tar.z")
+		{
+			str=str.left(str.length()-6);
+			str=str+".7z";
+			input->setText(str);
+		}
+		else if (ext1=="tbz2")
+		{
+			str=str.left(str.length()-5);
+			str=str+".7z";
+			input->setText(str);
+		}
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="rar" || ext1=="lzh")
+		{
+			str=str.left(str.length()-4);
+			str=str+".7z";
+			input->setText(str);
+		}
+		else if (ext1=="gz")
+		{
+			str=str.left(str.length()-3);
+			str=str+".7z";
+			input->setText(str);
+		}
+		else if (ext1=="z")
+		{
+			str=str.left(str.length()-2);
+			str=str+".7z";
+			input->setText(str);
+		}
+		else
+		{			
+			str=str+".7z";
+			input->setText(str);
+		}
+	}
+
 	else if (FXSELID(sel)==ID_FORMAT_RAR)
 	{
 		// Handle different archive formats
@@ -587,7 +644,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".rar";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="lzh")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="lzh")
 		{
 			str=str.left(str.length()-4);
 			str=str+".rar";
@@ -643,7 +700,7 @@ long ArchInputDialog::onCmdOption(FXObject*,FXSelector sel,void*)
 			str=str+".lzh";
 			input->setText(str);
 		}
-		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="rar")
+		else if (ext1=="tgz" || ext1=="bz2" || ext1=="tar" || ext1=="zip" || ext1=="7z" || ext1=="rar")
 		{
 			str=str.left(str.length()-4);
 			str=str+".lzh";
@@ -715,6 +772,10 @@ long ArchInputDialog::onUpdOption(FXObject*,FXSelector sel,void*)
 	{
 		optionmenu->setCurrent(option_zip);	
 	}
+	else if (ext1=="7z")
+	{
+		optionmenu->setCurrent(option_7zip);	
+	}
 	else if (ext1=="rar")
 	{
 		optionmenu->setCurrent(option_rar);	
