@@ -16,6 +16,7 @@ protected:
 	FXOptionMenu*		optionmenu;
 	FXOption* 			option_tgz;	
 	FXOption* 			option_zip;	
+	FXOption* 			option_7zip;	
 	FXOption* 			option_tbz2;	
 	FXOption* 			option_tar;	
 	FXOption* 			option_taz; 	
@@ -35,6 +36,7 @@ public:
         ID_BROWSE_PATH=DialogBox::ID_LAST,
 		ID_FORMAT_TAR_GZ,
 		ID_FORMAT_ZIP,
+		ID_FORMAT_7ZIP,
 		ID_FORMAT_TAR_BZ2,
 		ID_FORMAT_TAR,
 		ID_FORMAT_TAR_Z,
