@@ -791,6 +791,8 @@ long DirPanel::onCmdAddToArch(FXObject* o,FXSelector,void*)
             cmd="compress -v ";
 		else if (ext1=="zip")
             cmd="zip -r "+archive+" ";
+		else if (ext1=="7z")
+            cmd="p7zip ";
 		else if (ext1=="rar")
             cmd="rar a "+archive+" ";
 		else if (ext1=="lzh")
@@ -1336,14 +1338,14 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
     }
 
 	// Multiple sources and non existent destination
-	if (num>1 & !::exists(target))
+	if (num>1 && !::exists(target))
 	{
         MessageBox::error(this,BOX_OK,_("Error"),_("Folder %s doesn't exist"),target.text());
         return 0;
 	}
 		
 	// Multiple sources and target is a file
-	if (num>1 & ::isFile(target))
+	if (num>1 && ::isFile(target))
 	{ 			
         MessageBox::error(this,BOX_OK,_("Error"),_("%s is not a folder"),target.text());
         return 0;
@@ -1357,7 +1359,7 @@ long DirPanel::onCmdDirMan(FXObject* sender,FXSelector sel,void* ptr)
     }
 	
 	// Target is a file and its parent directory is not writable
-	if (::isFile(target) & !::isWritable(targetdir))
+	if (::isFile(target) && !::isWritable(targetdir))
 	{
         MessageBox::error(this,BOX_OK_SU,_("Error"),_("Can't write to %s: Permission denied"),targetdir.text());
         return 0;
