@@ -121,7 +121,7 @@ public:
 	// Change default cursor
 	void setDefaultCursor(FXCursor* cur)
 	{
-		list->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
+		list->setDefaultCursor(cur);
 	}
 
 	// Set current directory
