@@ -544,9 +544,9 @@ EditWindow::EditWindow(XFileWrite* a,const FXString& file):FXMainWindow(a,"XFile
 
     // Sites where to dock
     FXDockSite* topdock=new FXDockSite(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
-    FXDockSite* bottomdock=new FXDockSite(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
-    FXDockSite* leftdock=new FXDockSite(this,LAYOUT_SIDE_LEFT|LAYOUT_FILL_Y);
-    FXDockSite* rightdock=new FXDockSite(this,LAYOUT_SIDE_RIGHT|LAYOUT_FILL_Y);
+    new FXDockSite(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
+    new FXDockSite(this,LAYOUT_SIDE_LEFT|LAYOUT_FILL_Y);
+    new FXDockSite(this,LAYOUT_SIDE_RIGHT|LAYOUT_FILL_Y);
 
     // Toolbar
     dragshell=new FXToolBarShell(this,FRAME_RAISED);
