@@ -10,11 +10,20 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <dirent.h>
-#include <fox-1.6/fx.h>
+
+#include <fx.h>
 
 #include "DialogBox.h"
 
+// Single click types
+enum
+{
+	SINGLE_CLICK_NONE,
+	SINGLE_CLICK_DIR,
+	SINGLE_CLICK_DIR_FILE,
+};
 
+FXString quote(FXString);
 FXbool isUtf8(const FXchar* string, FXuint length);
 int statrep(const char *filename, struct stat *buf);
 int lstatrep(const char *filename, struct stat *buf);
@@ -80,6 +89,7 @@ class File : public DialogBox
     FXDECLARE(File)
 protected:
 	int checkTimeout(void);
+	int forceTimeout(void);
     long fullread(int fd, unsigned char *ptr, long len);
     long fullwrite(int fd, const unsigned char *ptr, long len);
     FXbool copyfile(const FXString& source, const FXString& target, const FXbool preserve_date);
