@@ -63,6 +63,7 @@ public:
     long onCmdHome(FXObject*,FXSelector,void*);
     long onCmdWork(FXObject*,FXSelector,void*);
 	long onCmdNewDir(FXObject*,FXSelector,void*);
+	long onCmdNewFile(FXObject*,FXSelector,void*);
 	long onCmdPopupMenu(FXObject*,FXSelector,void*);
 public:
     enum {
@@ -77,6 +78,7 @@ public:
         ID_HOME,
         ID_WORK,
 		ID_NEWDIR,
+		ID_NEWFILE,
         ID_LAST
     };
 public:
