@@ -9,6 +9,14 @@ struct FileAssoc;
 class  FileDict;
 class  FileList;
 
+// File List options (prefixed by underscore to avoid conflict with the FOX library)
+enum
+{
+	_FILELIST_SHOWHIDDEN   = 0x04000000, // Show hidden files or directories
+	_FILELIST_SHOWDIRS     = 0x08000000, // Show only directories
+	_FILELIST_SEARCH       = 0x10000000, // File list is a search list (must be the same value as in IconList)
+};
+
 // File item
 class FXAPI FileItem : public IconItem
 {
@@ -18,8 +26,9 @@ protected:
     FileAssoc  *assoc;                      // File association record
 	FileItem   *link;                   	// Link to next item
     unsigned long long size;                // File size
-    FXTime        date;                     // File time
-	FXTime		  deldate;
+    FXTime        date;                     // File date (mtime)
+	FXTime		  cdate;					// Changed date (ctime)
+	FXTime		  deldate;					// Deletion date
 protected:
     FileItem():assoc(NULL),link(NULL),size(0),date(0)
     {}
@@ -126,7 +135,6 @@ protected:
 	FXbool		ignorecase;				// Case sensitivity for file name sorting
 	FXbool		allowrefresh;			// Allow or disallow periodic refresh
 	FXbool		displaythumbnails;		// Display thumbnails
-	FXColor 	*tmpdata;				// Temporary image data
 	FXString	trashlocation;          // Location of the trash directory
 	FXbool      single;                 // Allow single click navigation for directories
 	FXbool		dirsfirst;				// Sort directories first
@@ -141,7 +149,8 @@ protected:
     FileList()
 	{}
     virtual IconItem *createItem(const FXString& text,FXIcon *big,FXIcon* mini,void* ptr);
-    void listItems();
+    void updateItems(FXbool);
+    void listItems(FXbool);
 private:
     FileList(const FileList&);
     FileList &operator=(const FileList&);
@@ -160,7 +169,9 @@ public:
     long onCmdDirectoryUp(FXObject*,FXSelector,void*);
     long onUpdDirectoryUp(FXObject*,FXSelector,void*);
 	long onCmdSortByName(FXObject*,FXSelector,void*);
+	long onCmdSortByDirName(FXObject*,FXSelector,void*);
 	long onUpdSortByName(FXObject*,FXSelector,void*);
+	long onUpdSortByDirName(FXObject*,FXSelector,void*);
 	long onCmdSortByType(FXObject*,FXSelector,void*);
 	long onUpdSortByType(FXObject*,FXSelector,void*);
 	long onCmdSortBySize(FXObject*,FXSelector,void*);
@@ -205,6 +216,10 @@ public:
 	static FXint descending(const IconItem* pa,const IconItem* pb);
 	static FXint ascendingCase(const IconItem* pa,const IconItem* pb);
 	static FXint descendingCase(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingDir(const IconItem* pa,const IconItem* pb);
+	static FXint descendingDir(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingDirCase(const IconItem* pa,const IconItem* pb);
+	static FXint descendingDirCase(const IconItem* pa,const IconItem* pb);
 	static FXint ascendingType(const IconItem* pa,const IconItem* pb);
 	static FXint descendingType(const IconItem* pa,const IconItem* pb);
 	static FXint ascendingSize(const IconItem* pa,const IconItem* pb);
@@ -221,11 +236,14 @@ public:
 	static FXint descendingPerm(const IconItem* pa,const IconItem* pb);
 	static FXint ascendingDeltime(const IconItem* pa,const IconItem* pb);
 	static FXint descendingDeltime(const IconItem* pa,const IconItem* pb);
-
 	static FXint ascendingMix(const IconItem* pa,const IconItem* pb);
 	static FXint descendingMix(const IconItem* pa,const IconItem* pb);
 	static FXint ascendingCaseMix(const IconItem* pa,const IconItem* pb);
 	static FXint descendingCaseMix(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingDirMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingDirMix(const IconItem* pa,const IconItem* pb);
+	static FXint ascendingDirCaseMix(const IconItem* pa,const IconItem* pb);
+	static FXint descendingDirCaseMix(const IconItem* pa,const IconItem* pb);
 	static FXint ascendingTypeMix(const IconItem* pa,const IconItem* pb);
 	static FXint descendingTypeMix(const IconItem* pa,const IconItem* pb);
 	static FXint ascendingSizeMix(const IconItem* pa,const IconItem* pb);
@@ -254,6 +272,7 @@ public:
         ID_SORT_BY_GROUP,
         ID_SORT_BY_PERM,   
         ID_SORT_BY_DELTIME,
+        ID_SORT_BY_DIRNAME,
         ID_SORT_REVERSE,
     	ID_SORT_CASE,
     	ID_DIRS_FIRST,
@@ -326,9 +345,12 @@ public:
 	// Return name of item at index
     FXString getItemFilename(FXint index) const;
 
-    // Return full pathname of item at index
+	// Get pathname from item at index, relatively to the current directory
     FXString getItemPathname(FXint index) const;
 
+	// Get full pathname from item at index, as obtained from the label string 
+    FXString getItemFullPathname(FXint index) const;
+
     // Return file association of item
     FileAssoc* getItemAssoc(FXint index) const;
 
