@@ -207,7 +207,7 @@ void IconItem::drawDetails(IconList* list,FXDC& dc,FXint x,FXint y,FXint,FXint h
     highlight = !highlight;
 	
 	// Darken the sorted column
-	for (hi=0; hi<list->getSortHeader(); hi++)
+	for (hi=0; hi<(FXint)list->getSortHeader(); hi++)
 		dx+=header->getItemSize(hi);
 
 	if (highlight)
