@@ -1,5 +1,5 @@
-#ifndef ICONLIST_H
-#define ICONLIST_H
+#ifndef _ICONLIST_H
+#define _ICONLIST_H
 
 #ifndef FXSCROLLAREA_H
 #include "FXScrollArea.h"
@@ -10,12 +10,30 @@ class IconList;
 class FileList;
 
 
+// Icon List options (prefixed by underscore to avoid conflict with the FOX library)
+enum {
+  _ICONLIST_EXTENDEDSELECT = 0,                // Extended selection mode
+  _ICONLIST_SINGLESELECT   = 0x00100000,       // At most one selected item
+  _ICONLIST_BROWSESELECT   = 0x00200000,       // Always exactly one selected item
+  _ICONLIST_MULTIPLESELECT = 0x00300000,       // Multiple selection mode
+  _ICONLIST_AUTOSIZE       = 0x00400000,       // Automatically size item spacing
+  _ICONLIST_DETAILED       = 0,                // List mode
+  _ICONLIST_MINI_ICONS     = 0x00800000,       // Mini Icon mode
+  _ICONLIST_BIG_ICONS      = 0x01000000,       // Big Icon mode
+  _ICONLIST_ROWS           = 0,                // Row-wise mode
+  _ICONLIST_COLUMNS        = 0x02000000,       // Column-wise mode
+  _ICONLIST_SEARCH         = 0x10000000,       // Icon list is a search list (must be the same value as in FileList)
+  _ICONLIST_NORMAL         = _ICONLIST_EXTENDEDSELECT
+  };
+
+
+
+
 // Icon item
 class FXAPI IconItem : public FXObject
 {
     FXDECLARE(IconItem)
     friend class IconList;
-    friend class FileList;
 protected:
     FXString  label;      // Text of item
     FXIcon   *bigIcon;    // Icon of item
@@ -214,7 +232,7 @@ protected:
 	FXuint			   numsortheader;     // Index of the sorted column
 	FXdouble           headerpct[9];      // Header sizes, relatively to the list width (in percent)
 	FXint			   count;             // Counter used to properly initialize the relative header sizes
-
+	FXbool 			   autosize;
 protected:
     IconList()
 	{}
@@ -271,6 +289,8 @@ public:
     long onCmdSetValue(FXObject*,FXSelector,void*);
     long onCmdGetIntValue(FXObject*,FXSelector,void*);
     long onCmdSetIntValue(FXObject*,FXSelector,void*);
+	long onCmdToggleAutosize(FXObject*,FXSelector,void*);
+	long onUpdToggleAutosize(FXObject* sender,FXSelector,void*);
 public:
     static FXint ascending(const IconItem* a,const IconItem* b);
     static FXint descending(const IconItem* a,const IconItem* b);
@@ -289,12 +309,13 @@ public:
         ID_SELECT_ALL,
         ID_DESELECT_ALL,
         ID_SELECT_INVERSE,
+        ID_AUTOSIZE,
         ID_LAST
     };
 public:
 
     // Construct icon list with no items in it initially
-    IconList(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=ICONLIST_NORMAL,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
+    IconList(FXComposite *p,FXObject* tgt=NULL,FXSelector sel=0,FXuint opts=_ICONLIST_NORMAL,FXint x=0,FXint y=0,FXint w=0,FXint h=0);
 
     // Create server-side resources
     virtual void create();
