@@ -120,7 +120,7 @@ void PathLinker::setPath(FXString text)
     }
 
     visitedPath = path;
-    FXint textWidth = normalFont->getTextWidth(path.text(), path.length());
+    //FXint textWidth = normalFont->getTextWidth(path.text(), path.length());
 
     FXString displayText = visitedPath;
     
@@ -191,8 +191,8 @@ void PathLinker::updatePath(FXString text, FXuint index)
     }
 
     visitedPath = path;
-    FXFont* normalFont = getApp()->getNormalFont();
-    FXint textWidth = normalFont->getTextWidth(path.text(), path.length());
+    //FXFont* normalFont = getApp()->getNormalFont();
+    //FXint textWidth = normalFont->getTextWidth(path.text(), path.length());
 
     FXString displayText = visitedPath;
     
