@@ -928,17 +928,9 @@ long PreferencesBox::onCmdAccept(FXObject* o,FXSelector s,void* p)
 		single_click=SINGLE_CLICK_NONE;
 	
 	if (single_click==SINGLE_CLICK_DIR_FILE)
-	{
-		((XFileExplorer*) mainWindow)->lpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
-		((XFileExplorer*) mainWindow)->rpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
-		((XFileExplorer*) mainWindow)->dirpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
-	}
+		((XFileExplorer*) mainWindow)->setDefaultCursor(getApp()->getDefaultCursor(DEF_HAND_CURSOR));
 	else
-	{
-		((XFileExplorer*) mainWindow)->lpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
-		((XFileExplorer*) mainWindow)->rpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
-		((XFileExplorer*) mainWindow)->dirpanel->list->setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
-	}
+		((XFileExplorer*) mainWindow)->setDefaultCursor(getApp()->getDefaultCursor(DEF_ARROW_CURSOR));
    
 	// Update the file tooltips flag
 	if (filetooltips->getCheck())
