@@ -10,12 +10,12 @@
 #define COLORS_NUM 9
 
 // Number of themes
-#define THEMES_NUM 12
+#define THEMES_NUM 13
 
 
 struct Theme
 {
-    char *name;
+    const char *name;
     FXColor color[9];
     Theme()
     {
@@ -35,7 +35,7 @@ struct Theme
 		color[7] = listfg;
  		color[7] = listfg;
   		color[8] = listhl;
-  };
+	};
     FXbool operator != (const Theme&);
 };
 
@@ -45,7 +45,6 @@ class PreferencesBox : public DialogBox
 private:
     PreferencesBox()
     {}
-    FXButton   *cwell;
     FXComboBox *colorsBox;
     FXComboBox *themesBox;
     FXList     *themesList;
@@ -56,6 +55,9 @@ private:
     FXTextField *xterm;
     FXTextField *imgeditor;
     FXTextField *archiver;
+    FXTextField *pdfviewer;
+    FXTextField *videoviewer;
+    FXTextField *audioviewer;
     FXTextField *normalfont;
     FXTextField *textfont;
     FXString    oldiconpath;
@@ -67,9 +69,15 @@ private:
     FXString    oldtextfont;
     FXString    oldimgeditor;
     FXString    oldarchiver;
+    FXString    oldpdfviewer;
+    FXString    oldvideoviewer;
+    FXString    oldaudioviewer;
     FXCheckButton  *autosave;
     FXCheckButton  *diropen;
     FXCheckButton  *fileopen;
+    FXCheckButton  *filetooltips;
+    FXCheckButton  *relativeresize;
+    FXCheckButton  *showpathlink;
     FXCheckButton  *quit;
     FXCheckButton  *trashcan;
     FXCheckButton  *trashbypass;
@@ -82,6 +90,9 @@ private:
     FXCheckButton  *root_warning;
     FXCheckButton  *mount;
 	FXCheckButton  *show_mount;
+	FXCheckButton  *scroll;
+	FXCheckButton  *controls;
+	FXColorWell    *cwell;
     Theme          Themes[THEMES_NUM];
     Theme          currTheme;
     Theme          currTheme_prev;
@@ -92,6 +103,10 @@ private:
 	FXbool		   autosave_prev;
 	FXbool         diropen_prev;
 	FXbool         fileopen_prev;
+	FXbool         filetooltips_prev;
+	FXbool         relativeresize_prev;
+	FXbool         show_pathlink;
+	FXbool         show_pathlink_prev;
 	FXuint	       value_prev;
 	FXbool		   ask_prev;
 	FXbool		   dnd_prev;
@@ -99,19 +114,26 @@ private:
 	FXbool		   del_emptydir_prev;
 	FXbool		   overwrite_prev;
 	FXbool		   quit_prev;
+	FXbool		   controls_prev;
 #if defined(linux)
 	FXbool		   mount_prev;
 	FXbool		   show_mount_prev;
 #endif
 	FXbool		   root_warning_prev;
 	FXuint		   themelist_prev;
+	FXbool		   smoothscroll_prev;
 public:
-    enum{
+    enum
+	{
         ID_ACCEPT=DialogBox::ID_LAST,
 		ID_CANCEL,
         ID_BROWSE_TXTEDIT,
         ID_BROWSE_TXTVIEW,
 		ID_BROWSE_IMGVIEW,
+		ID_BROWSE_ARCHIVER,
+		ID_BROWSE_PDFVIEW,
+		ID_BROWSE_VIDEOVIEW,
+		ID_BROWSE_AUDIOVIEW,
         ID_BROWSE_XTERM,
         ID_COLOR,
 		ID_NORMALFONT,
@@ -124,6 +146,9 @@ public:
 		ID_SUDO_CMD,
 		ID_WHEELADJUST,
 		ID_SINGLE_CLICK_FILEOPEN,
+		ID_FILE_TOOLTIPS,
+		ID_RELATIVE_RESIZE,
+		ID_SHOW_PATHLINK,
         ID_LAST
     };
 
