@@ -215,7 +215,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 	extension=file.rafter('.',1);
 	extension=extension.lower();
 	if (extension=="gz" || extension=="tgz" || extension=="tar" || extension=="bz2" ||
-		extension=="tbz2" || extension=="zip" || extension=="Z" || extension=="lzh" || extension=="rar")
+		extension=="tbz2" || extension=="zip" || extension=="7z" || extension=="Z" || extension=="lzh" || extension=="rar")
 	{
 		is_ar = TRUE; // archive
 		viewlbl = _("Extract:");
@@ -429,7 +429,7 @@ PropertiesBox::PropertiesBox(FXWindow *win,FXString file,FXString path): DialogB
 		input->setEditable(FALSE);
 
 	// Root directory name not editable
-    if (file=="" & path==ROOTDIR)
+    if (file=="" && path==ROOTDIR)
 	{
 		input->setText(ROOTDIR);
 		input->setEditable(FALSE);
