@@ -1,9 +1,9 @@
 #ifndef TEXTWINDOW_H
 #define TEXTWINDOW_H
 
+#include "DialogBox.h"
 
-
-class TextWindow : public FXDialogBox
+class TextWindow : public DialogBox
 {
     FXDECLARE(TextWindow)
 protected:
@@ -14,11 +14,12 @@ private:
     TextWindow(const TextWindow&);
 public:
     enum{
-        ID_CLOSE=FXDialogBox::ID_LAST,
+        ID_CLOSE=DialogBox::ID_LAST,
         ID_LAST
     };
 public:
-    TextWindow(FXWindow *owner, const FXString& name, FXint nblines, FXint nbcols);
+    TextWindow(FXWindow* owner, const FXString& name, FXint nblines, FXint nbcols);
+    TextWindow(FXApp* app, const FXString& name, FXint nblines, FXint nbcols);
     virtual ~TextWindow();
 	void setText(const FXchar*);
 	void appendText(const FXchar* str);
