@@ -160,10 +160,10 @@ XFileExplorer::XFileExplorer(FXApp *app, const FXbool iconic, const FXbool maxim
 
 	// Sites where to dock (for toolbars)
 	FXDockSite* topdock=new FXDockSite(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
-	FXDockSite* bottomdock=new FXDockSite(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
-	FXDockSite* leftdock=new FXDockSite(this,LAYOUT_SIDE_LEFT|LAYOUT_FILL_Y);
-	FXDockSite* rightdock=new FXDockSite(this,LAYOUT_SIDE_RIGHT|LAYOUT_FILL_Y);
-
+	new FXDockSite(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
+	new FXDockSite(this,LAYOUT_SIDE_LEFT|LAYOUT_FILL_Y);
+	new FXDockSite(this,LAYOUT_SIDE_RIGHT|LAYOUT_FILL_Y);
+	
     // General toolbar
   	FXToolBarShell* dragshell1=new FXToolBarShell(this,FRAME_RAISED);
   	generaltoolbar=new FXToolBar(topdock,dragshell1,LAYOUT_DOCK_NEXT|LAYOUT_SIDE_TOP|FRAME_RAISED);
@@ -401,7 +401,6 @@ XFileExplorer::XFileExplorer(FXApp *app, const FXbool iconic, const FXbool maxim
 	rpanel->setDirsFirst(dirs_first);        
 
     FXButton *btn=NULL;
-    FXToggleButton *tgbtn=NULL;
 
     // General toolbar
     btn=new FXButton(generaltoolbar,_("\tGo back (Ctrl-Backspace)"),dirbackicon,this,XFileExplorer::ID_DIR_BACK,BUTTON_TOOLBAR|FRAME_RAISED|LAYOUT_TOP|LAYOUT_LEFT);
@@ -1396,7 +1395,6 @@ long  XFileExplorer::onCmdDirBack(FXObject*,FXSelector,void*)
 // Update directory back
 long  XFileExplorer::onUpdDirBack(FXObject* sender, FXSelector, void* ptr)
 {
-	StringItem *item;
 	FXString pathname;
 	FilePanel* filepanel=lpanel->getCurrent();
 	
@@ -1444,7 +1442,6 @@ long  XFileExplorer::onCmdDirForward(FXObject*,FXSelector,void*)
 // Update directory forward
 long  XFileExplorer::onUpdDirForward(FXObject* sender, FXSelector sel, void* ptr)
 {
-	StringItem *item;
 	FXString pathname;
 	FilePanel* filepanel=lpanel->getCurrent();
 
@@ -1538,7 +1535,6 @@ long  XFileExplorer::onCmdDirBackHist(FXObject *sender,FXSelector sel,void* ptr)
 // Update directory back
 long  XFileExplorer::onUpdDirBackHist(FXObject* sender, FXSelector sel, void* ptr)
 {
-	StringItem *item;
 	FXString pathname;
 	FilePanel* filepanel=lpanel->getCurrent();
 
@@ -1632,7 +1628,6 @@ long  XFileExplorer::onCmdDirForwardHist(FXObject *sender,FXSelector sel,void* p
 // Update directory forward
 long  XFileExplorer::onUpdDirForwardHist(FXObject* sender, FXSelector sel, void* ptr)
 {
-	StringItem *item;
 	FXString pathname;
 	FilePanel* filepanel=lpanel->getCurrent();
 
