@@ -31,12 +31,6 @@ void toolbarSeparator(FXToolBar*);
 class XFileExplorer : public FXMainWindow
 {
     FXDECLARE(XFileExplorer)
-    friend class FilePanel;
-    friend class DirPanel;
-    friend class DirList;
-    friend class PathLinker;
-	friend class PropertiesBox;
-	friend class PreferencesBox;
 protected:
 	enum
 	{
@@ -151,10 +145,6 @@ public:
     virtual void create();
     ~XFileExplorer();
     void saveConfig();
-    FileDict *getAssociations()
-    {
-        return lpanel->current->list->getAssociations();
-    }
     long onQuit(FXObject*,FXSelector,void*);
 	long onKeyPress(FXObject*,FXSelector,void*);
 	long onCmdHelp(FXObject*,FXSelector,void*);
@@ -206,5 +196,51 @@ public:
 	long onUpdSynchronizePanels(FXObject*,FXSelector,void*);
 	long onCmdSwitchPanels(FXObject*,FXSelector,void*);
 	long onUpdSwitchPanels(FXObject*,FXSelector,void*);
+public:
+    // Get associations
+    FileDict *getAssociations()
+    {
+        return lpanel->getCurrent()->getAssociations();
+    }
+
+	// Change to selected directory
+	void setDirectory(FXString pathname)
+	{
+		lpanel->getCurrent()->setDirectory(pathname,FALSE);
+		lpanel->getCurrent()->updatePathLinker();
+	}
+
+	// Change default cursor for file and dir panels
+	void setDefaultCursor(FXCursor *cur)
+	{
+		lpanel->setDefaultCursor(cur);
+		rpanel->setDefaultCursor(cur);
+		dirpanel->setDefaultCursor(cur);
+	}
+
+	// Redraw file lists
+	void redrawPanels(void)
+	{
+		lpanel->redraw();
+		rpanel->redraw();
+	}
+
+	// Return a pointer on the current file panel
+	FilePanel* getCurrentPanel(void)
+	{
+		return lpanel->getCurrent();	
+	}
+
+	// Return the address box (location bar)
+	FXComboBox* getAddressBox(void)
+	{
+		return address;
+	}
+
+	// Return a pointer on the directory panel
+	DirPanel* getDirPanel(void)
+	{
+		return dirpanel;	
+	}
 };
 #endif
