@@ -191,9 +191,9 @@ XFileImage::XFileImage(FXApp* a):FXMainWindow(a,"Xfi ",NULL,NULL,DECOR_ALL)
 
 	// Sites where to dock
 	FXDockSite* topdock=new FXDockSite(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
-	FXDockSite* bottomdock=new FXDockSite(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
-	FXDockSite* leftdock=new FXDockSite(this,LAYOUT_SIDE_LEFT|LAYOUT_FILL_Y);
-	FXDockSite* rightdock=new FXDockSite(this,LAYOUT_SIDE_RIGHT|LAYOUT_FILL_Y);
+	new FXDockSite(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
+	new FXDockSite(this,LAYOUT_SIDE_LEFT|LAYOUT_FILL_Y);
+	new FXDockSite(this,LAYOUT_SIDE_RIGHT|LAYOUT_FILL_Y);
 
     // Tool bar
   	FXToolBarShell* dragshell1=new FXToolBarShell(this,FRAME_RAISED);
@@ -599,15 +599,12 @@ long  XFileImage::onCmdDirBack(FXObject*,FXSelector s,void* p)
 long  XFileImage::onUpdDirBack(FXObject* sender, FXSelector sel, void* ptr)
 {
 	StringList *backhist;
-	StringItem *item;
 	FXString pathname;
 
 	// Get the filelist history
 	backhist=filelist->backhist;
 	
 	// Gray out the button if no item in history 
-	FXint num=backhist->getNumItems();
-		
 	if (backhist->getNumItems()==0)
 		sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),ptr);	
 	else
@@ -649,14 +646,12 @@ long  XFileImage::onCmdDirForward(FXObject*,FXSelector s,void* p)
 long  XFileImage::onUpdDirForward(FXObject* sender, FXSelector sel, void* ptr)
 {
 	StringList *forwardhist;
-	StringItem *item;
 	FXString pathname;
 
 	// Get the filelist history
 	forwardhist=filelist->forwardhist;
 	
 	// Gray out the button if no item in history 
-	FXint num=forwardhist->getNumItems();
 	if (forwardhist->getNumItems()==0)
 		sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),ptr);	
 	else
@@ -737,14 +732,12 @@ long  XFileImage::onCmdDirBackHist(FXObject *sender,FXSelector sel,void* ptr)
 long  XFileImage::onUpdDirBackHist(FXObject* sender, FXSelector sel, void* ptr)
 {
 	StringList *backhist;
-	StringItem *item;
 	FXString pathname;
 
 	// Get the filelist history
 	backhist=filelist->backhist;
 	
 	// Gray out the button if no item in history 
-	FXint num=backhist->getNumItems();
 	if (backhist->getNumItems()==0)
 		sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),ptr);	
 	else
@@ -824,14 +817,12 @@ long  XFileImage::onCmdDirForwardHist(FXObject *sender,FXSelector sel,void* ptr)
 long  XFileImage::onUpdDirForwardHist(FXObject* sender, FXSelector sel, void* ptr)
 {
 	StringList *forwardhist;
-	StringItem *item;
 	FXString pathname;
 
 	// Get the filelist history
 	forwardhist=filelist->forwardhist;
 	
 	// Gray out the button if no item in history 
-	FXint num=forwardhist->getNumItems();
 	if (forwardhist->getNumItems()==0)
 		sender->handle(this,FXSEL(SEL_COMMAND,ID_DISABLE),ptr);
 	else
