@@ -11,7 +11,7 @@ protected:
 	FXbool             hiddenfiles;           // Show or hide hidden files
 	FXbool             thumbnails;            // Show or hide image thumbnails
 	FXuint             fileview;              // File list view
-	FXuint             iconview;              // Icon organization
+	FXuint			   liststyle;             // Icon list style
     FXImageView       *imageview;             // Image viewer
     FXRecentFiles      mrufiles;              // Recent files
     FXString           filename;              // File being viewed
@@ -53,6 +53,7 @@ public:
  	long onCmdShowDetails(FXObject*,FXSelector,void*);
  	long onCmdShowRows(FXObject*,FXSelector,void*);
  	long onCmdShowCols(FXObject*,FXSelector,void*);
+ 	long onCmdAutosize(FXObject*,FXSelector,void*);
 	long onCmdSave(FXObject*,FXSelector,void*);
     long onCmdQuit(FXObject*,FXSelector,void*);
     long onUpdTitle(FXObject*,FXSelector,void*);
@@ -98,6 +99,7 @@ public:
 		ID_SHOW_DETAILS,
 		ID_COLS,
 		ID_ROWS,
+		ID_AUTO,
         ID_TITLE,
 		ID_PRINT,
         ID_QUIT,
