@@ -99,9 +99,9 @@ XFilePackage::XFilePackage(FXApp *a):FXMainWindow(a,"Xfp",NULL,NULL,DECOR_ALL)
 
 	// Sites where to dock
 	FXDockSite* topdock=new FXDockSite(this,LAYOUT_SIDE_TOP|LAYOUT_FILL_X);
-	FXDockSite* bottomdock=new FXDockSite(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
-	FXDockSite* leftdock=new FXDockSite(this,LAYOUT_SIDE_LEFT|LAYOUT_FILL_Y);
-	FXDockSite* rightdock=new FXDockSite(this,LAYOUT_SIDE_RIGHT|LAYOUT_FILL_Y);
+	new FXDockSite(this,LAYOUT_SIDE_BOTTOM|LAYOUT_FILL_X);
+	new FXDockSite(this,LAYOUT_SIDE_LEFT|LAYOUT_FILL_Y);
+	new FXDockSite(this,LAYOUT_SIDE_RIGHT|LAYOUT_FILL_Y);
 
     // Tool bar
   	FXToolBarShell* dragshell1=new FXToolBarShell(this,FRAME_RAISED);
