@@ -18,7 +18,7 @@ protected:
     FXText 				*description;		// Package description
     FXbool 				desc_clean;			// Clean description flag
     FXbool 				list_clean;			// Clean list flag
-	FileDialog*         opendialog;
+	FXbool				smoothscroll;
 protected:
     XFilePackage()
     {}
@@ -37,6 +37,10 @@ public:
     void create();
     XFilePackage(FXApp *a);
 	~XFilePackage();
+	void setSmoothScroll(FXbool smooth)
+	{
+		smoothscroll=smooth;
+	}
     long onCmdUninstall(FXObject*,FXSelector,void*);
     long onCmdInstall(FXObject*,FXSelector,void*);
 	long onCmdAbout(FXObject*,FXSelector,void*);
