@@ -11,8 +11,7 @@ class EditWindow;
 class XFileWrite : public FXApp
 {
     FXDECLARE(XFileWrite)
-    friend class EditWindow;
-protected:
+public:
     EditWindowList  windowlist;                   // Window list
 private:
     XFileWrite()
