@@ -96,6 +96,7 @@ static FXint utf2db(XChar2b *dst,const FXchar *src,FXint n)
     return len;
 }
 
+
 // Hack to take into account non UTF-8 strings
 void FXDCWindow::drawText(FXint x,FXint y,const FXchar* string,FXuint length)
 {
@@ -790,7 +791,7 @@ bool FXWindow::getDNDData(FXDNDOrigin origin,FXDragType targettype,FXuchar*& dat
 // Draw rectangle with gradient effect
 static void drawGradientRectangle(FXDC& dc,FXColor lower,FXColor upper,FXint x,FXint y,FXint w,FXint h)
 {
-    register FXint rr,gg,bb,dr,dg,db,r1,g1,b1,r2,g2,b2,xl,xh,yl,yh,xx,yy,dy,dx,n,t;
+    register FXint rr,gg,bb,dr,dg,db,r1,g1,b1,r2,g2,b2,yl,yh,yy,dy,n,t;
     const FXint MAXSTEPS=128;
     if (0<w && 0<h)
     {
