@@ -8,7 +8,7 @@
 \n \
                                   XFE, X File Explorer File Manager\n \
 \n \
-                               Copyright (C) 2002-2007 Roland Baudin\n \
+                               Copyright (C) 2002-2008 Roland Baudin\n \
 \n \
                                     <http://roland65.free.fr/xfe>\n \
                                 <http://sourceforge.net/projects/xfe>\n \
@@ -35,15 +35,16 @@ Xfe is based on the popular, but discontinued X Win Commander, written by Maxim
   =-=-=-=-=\n \
 \n \
   - Very fast graphic user interface\n \
+  - UTF-8 support\n \
   - Commander/Explorer interface with four file manager modes : a) one panel, b) a directory tree\n \
     and one panel, c) two panels and d) a directory tree and two panels\n \
+  - Panels synchronization and switching\n \
   - Integrated text editor (X File Write, xfw)\n \
   - Integrated text viewer (X File View, xfv)\n \
   - Integrated image viewer (X File Image, xfi)\n \
   - Integrated package (rpm or deb) viewer / installer / uninstaller (X File Package, xfp)\n \
-  - UTF-8 support\n \
-  - Copy/Cut/Paste files from and to your favorite desktop (GNOME/KDE/XFCE)\n \
-  - Drag and Drop files from and to your favorite desktop\n \
+  - Copy/Cut/Paste files from and to your favorite desktop (GNOME/KDE/XFCE/ROX)\n \
+  - Drag and Drop files from and to your favorite desktop (GNOME/KDE/XFCE/ROX)\n \
   - Root mode with authentication by su or sudo\n \
   - Status line\n \
   - File associations\n \
@@ -58,7 +59,8 @@ Xfe is based on the popular, but discontinued X Win Commander, written by Maxim
   - Bookmarks\n \
   - Back and forward history lists for directory navigation\n \
   - Color themes (GNOME, KDE, Windows...)\n \
-  - Icon themes (Xfe, GNOME, XFCE, Windows...)\n \
+  - Icon themes (Xfe, GNOME, KDE, XFCE, Tango, Windows...)\n \
+  - Control themes (flat or rounded gradient)\n \
   - Create/Extract archives (tar, zip, gzip, bzip2, lzh, rar compress formats are supported)\n \
   - Tooltips with file properties\n \
   - Progress bars or dialogs for lengthy file operations\n \
@@ -80,9 +82,10 @@ Xfe is based on the popular, but discontinued X Win Commander, written by Maxim
     o Cut                          - Ctrl-x\n \
     o Paste                        - Ctrl-v\n \
     o Move                         - F6, Ctrl-d\n \
-    o Symlink                      - Ctrl-s\n \
+    o Symlink to                   - Ctrl-s\n \
     o Rename                       - Ctrl-n\n \
     o New folder                   - F7\n \
+    o New symlink                  - Ctrl-j\n \
     o Open                         - Ctrl-o\n \
     o Move to trash                - F8, del\n \
     o Delete                       - Shift-del\n \
@@ -96,6 +99,8 @@ Xfe is based on the popular, but discontinued X Win Commander, written by Maxim
     o Tree and one panel           - Ctrl-F2\n \
     o Two panels                   - Ctrl-F3\n \
     o Tree and two panels          - Ctrl-F4\n \
+    o Synchronize panels           - Ctrl-y\n \
+    o Switch panels                - Ctrl-p\n \
     o Large icons                  - F10\n \
     o Small icons                  - F11\n \
     o Detailed view                - F12\n \
@@ -152,6 +157,7 @@ File list\n \
 \n \
 Tree list\n \
    - Select a folder and right click to open a context menu on the selected folder\n \
+   - Press Ctrl + right click to open a context menu on the tree panel\n \
    - When dragging a file/folder to a folder, hold on the mouse on the folder\n \
      to expand it\n \
 \n \
@@ -180,7 +186,7 @@ Xfe is now available in 18 languages. To translate Xfe to your language, open wi
   Patches\n \
   =-=-=-=\n \
 \n \
-If you've done some interesting patch, please send it to me, I will try to include it in the next release...\n \
+If you have done some interesting patch, please send it to me, I will try to include it in the next release...\n \
 \n \
 [Many thanks to Maxim Baranov for his excellent X Win Commander and to all people that have provided useful patches,\n \
 tests and advices.]\n \
