@@ -152,12 +152,12 @@
 
 // Default archiver program
 #ifndef DEFAULT_ARCHIVER
-#define DEFAULT_ARCHIVER "file-roller"
+#define DEFAULT_ARCHIVER "xarchiver"
 #endif
 
 // Default PDF viewer program
 #ifndef DEFAULT_PDFVIEWER
-#define DEFAULT_PDFVIEWER "acroread"
+#define DEFAULT_PDFVIEWER "xpdf"
 #endif
 
 // Default audio viewer program
